@@ -1,4 +1,5 @@
 from __future__ import annotations  # Required for type hinting in class methods
+from typing import Optional
 
 import mysql.connector
 from logger_local.LoggerLocal import Logger
@@ -55,7 +56,7 @@ class Connector(metaclass=MetaLogger, object=LOGGER_CONNECTOR_CODE_OBJECT):
             logger.warning(
                 f"Your RDS_HOSTNAME={self.host} which is not what is expected")
         self.connection: mysql.connector = None
-        self._cursor: Cursor or None = None
+        self._cursor: Optional[Cursor] = None
         self._connect_to_db()
         connections_pool[schema_name] = self
 
@@ -102,7 +103,7 @@ class Connector(metaclass=MetaLogger, object=LOGGER_CONNECTOR_CODE_OBJECT):
 
         self.connection.commit()
 
-    def set_schema(self, new_schema: str or None) -> None:
+    def set_schema(self, new_schema: Optional[str]) -> None:
         if not new_schema:
             return
         if self.schema == new_schema:
