@@ -79,6 +79,10 @@ class GenericCRUD(metaclass=MetaLogger, object=LOGGER_CRUD_CODE_OBJECT):
         insert_query = "INSERT " + \
                        f"INTO `{schema_name}`.`{table_name}` ({columns}) " \
                        f"VALUES ({values});"
+        # Log query without parameters
+        values_str = ', '.join(f"'{value}'" for value in data_json.values())
+        insert_query_without_parameters = f"INSERT INTO `{schema_name}`.`{table_name}` ({columns}) VALUES ({values_str});"
+        self.logger.info("GenericCRUD.insert", object={"insert_query_without_parameters": insert_query_without_parameters})
         try:
             self.cursor.execute(insert_query, tuple(data_json.values()))
             if commit_changes:
@@ -415,7 +419,7 @@ class GenericCRUD(metaclass=MetaLogger, object=LOGGER_CRUD_CODE_OBJECT):
         return result
 
     def select_multi_dict_by_where(
-            self, *, schema_name: str = None, view_table_name: str, select_clause_value: str = None,
+            self, *, schema_name: str = None, view_table_name: str = None, select_clause_value: str = None,
             where: str = None, params: tuple = None, distinct: bool = False,
             limit: int = DEFAULT_SQL_SELECT_LIMIT, order_by: str = None) -> list:
         """Selects multiple rows from the table based on a WHERE clause and returns them as a list of dictionaries."""
@@ -500,6 +504,34 @@ class GenericCRUD(metaclass=MetaLogger, object=LOGGER_CRUD_CODE_OBJECT):
         else:
             return False
 
+    def __get_entity_type_by_table_name(self, table_name: str) -> int:
+        """Returns the entity_type_id of the table."""
+        if table_name in table_definition:
+            entity_type_id = table_definition[table_name].get("entity_type_id1")
+            return entity_type_id
+        else:
+            return None
+
+
+    def __add_identifier(self, data_json: dict, table_name: str) -> None:
+        # If there's an "identifier" column in the table, we want to insert a random identifier
+        #  to the identifier_table and use it in the data_json.
+        identifier_entity_type_id = self.__get_entity_type_by_table_name(table_name)
+        if not identifier_entity_type_id:
+            return None
+            # TODO Please add maximum infomation to any exception i.e. table_name, data_json ...
+            # raise Exception("Could not find the entity_type_id1 for table " + table_name + " in database.table_definition_table")
+
+        identifier = NumberGenerator.get_random_identifier(schema_name="identifier",
+                                                           view_name="identifier_view",
+                                                           identifier_column_name="identifier")
+        data_json["identifier"] = identifier
+        insert_query = "INSERT " + \
+                       "INTO `identifier`.`identifier_table` (identifier, entity_type_id) " \
+                       "VALUES (%s, %s);"
+        self.cursor.execute(insert_query, (identifier, identifier_entity_type_id))
+        self.connection.commit()
+
     # TODO: add warning logs
     def __add_create_updated_user_profile_ids(self, data_json: dict, add_created_user_id: bool = False,
                                               schema_name: str = None, table_name: str = None) -> dict:
@@ -533,13 +565,10 @@ class GenericCRUD(metaclass=MetaLogger, object=LOGGER_CRUD_CODE_OBJECT):
                     data_json["number"] = number
                 else:
                     self.__log_warning("number", schema_name, table_name)
+
                 if "identifier" in columns_dict:
-                    # TODO: the commented line caused errors, we need to check it
-                    # view_name = self.default_view_table_name or self._get_view_name(table_name)
-                    view_name = table_name
-                    identifier = NumberGenerator.get_random_identifier(schema_name=schema_name, view_name=view_name,
-                                                                       identifier_column_name="identifier")
-                    data_json["identifier"] = identifier
+                    self.__add_identifier(data_json=data_json, table_name=table_name)
+
                 else:
                     self.__log_warning("identifier", schema_name, table_name)
             if "updated_user_id" in columns_dict:
@@ -576,9 +605,8 @@ class GenericCRUD(metaclass=MetaLogger, object=LOGGER_CRUD_CODE_OBJECT):
                 view_name = table_name
                 number = NumberGenerator.get_random_number(schema_name=schema_name, view_name=view_name)
                 data_json["number"] = number
-                identifier = NumberGenerator.get_random_identifier(schema_name=schema_name, view_name=view_name,
-                                                                   identifier_column_name="identifier")
-                data_json["identifier"] = identifier
+
+                # self.__add_identifier(data_json=data_json)
             data_json["updated_user_id"] = self.user_context.get_effective_user_id()
             data_json["updated_real_user_id"] = self.user_context.get_real_user_id()
             data_json["updated_effective_user_id"] = self.user_context.get_effective_user_id()
